===============================
Salt Mill
===============================

.. image:: https://img.shields.io/travis/glasslion/salt-mill.svg
        :target: https://travis-ci.org/glasslion/salt-mill

.. image:: https://img.shields.io/pypi/v/salt-mill.svg
        :target: https://pypi.python.org/pypi/salt-mill


Saltstack API Client for Humans

* Free software: BSD license
* Documentation: https://salt-mill.readthedocs.org.

Features
--------

* TODO
